: '
 This script generates javadocs for develop branch and moves them into gh-pages branch
 and pushes the changes to the repository on github.

 Generally timestamp is changed in the javadoc files each time we generate the files from mvn javadoc:javadoc
 Commit is not performed if the changes are only related to timestamp.
'
#!/bin/bash

set -ev

#checkout the develop branch
git checkout develop
#verify that we are on develop branch, otherwise exit with error code
output=$(git rev-parse --abbrev-ref HEAD)
if [ "$output" = "develop" ]; then
	echo "On develop branch"
else
	echo "Failed to switch to develop branch"
	exit 1
fi

#generate javadocs for files in develop branch
mvn javadoc:javadoc;

#checkout gh-pages branch
git checkout -b gh-pages --track origin/gh-pages
#verify that we are on gh-pages branch, otherwise exit with error code
output=$(git rev-parse --abbrev-ref HEAD)
if [ "$output" = "gh-pages" ]; then
	echo "On gh-pages branch"
else
	echo "Failed to switch to gh-pages branch"
	exit 1
fi

#empty the folders html/java-docs/server-apis, html/java-docs/client-apis and html/java-docs/codegen-apis
rm -rf html/java-docs/server-apis/*
rm -rf html/java-docs/client-apis/*
rm -rf html/java-docs/codegen-apis/*

#copy the javadoc files to respective folders from develop branch into gh-pages branch
cp -R client/target/site/apidocs/* html/java-docs/client-apis/
cp -R codegen/target/site/apidocs/* html/java-docs/codegen-apis/
cp -R server/target/site/apidocs/* html/java-docs/server-apis/

#remove the temporary file used to output the git diff, if it is present
rm -rf target/changesDiff.txt

#get only the lines that are changed in the files (either added or deleted lines and/or files) and store them in target/changesDiff.txt
git diff HEAD --color=always|perl -wlne 'print $1 if /^\e\[32m\+\e\[m\e\[32m(.*)\e\[m$/' > target/changesDiff.txt

#if the changes in the javadoc files are not meta data, commit the changes in gh-pages branch and push the changes to remote
#otherwise stash the changes
if egrep -civ '^(<meta name|<!-- Generated by javadoc)' target/changesDiff.txt; then
	git add html/java-docs/* -A
	git commit -m "Update javadocs"
	git push origin gh-pages
else
	echo "No changes to javadocs, so no updates are pushed to gh-pages branch"
fi
